@@ -86,7 +86,7 @@ MainWindow::initialize()
     if (dlsInfo.exists() && dlsInfo.isReadable()) {
         readSoundfont(dlsInfo);
     } else {
-        ui->lblDLSFileName->setText("[empty]");
+        ui->lblSFFileName->setText("[empty]");
         m_dlsFile.clear();
         ProgramSettings::instance()->setDLSsoundfont(m_dlsFile);
         m_synth->renderer()->initSoundfont(m_dlsFile);
@@ -193,7 +193,7 @@ void MainWindow::readSoundfont(const QFileInfo &file)
 {
     if (file.exists() && file.isReadable()) {
         m_dlsFile = file.absoluteFilePath();
-        ui->lblDLSFileName->setText(file.fileName());
+        ui->lblSFFileName->setText(file.fileName());
         m_synth->renderer()->initSoundfont(m_dlsFile);
         ProgramSettings::instance()->setDLSsoundfont(m_dlsFile);
     }
@@ -202,9 +202,11 @@ void MainWindow::readSoundfont(const QFileInfo &file)
 void
 MainWindow::openMIDIFile()
 {
-    QString fileName = QFileDialog::getOpenFileName(this,
-        tr("Open MIDI file"), QDir::homePath(),
-        tr("MIDI Files (*.mid *.midi *.kar)"));
+    QString fileName
+        = QFileDialog::getOpenFileName(this,
+                                       tr("Open MIDI file"),
+                                       QString(),
+                                       tr("MIDI Files (*.mid *.midi *.kar *.rmi *.xmf *.mxmf)"));
     if (fileName.isEmpty()) {
         ui->lblSong->setText("[empty]");
         updateState(EmptyState);
@@ -218,11 +220,12 @@ void
 MainWindow::openDLSFile()
 {
     QString fileName = QFileDialog::getOpenFileName(this,
-        tr("Open DLS file"), QDir::homePath(),
-        tr("DLS Files (*.dls)"));
+                                                    tr("Open SoundFont file"),
+                                                    QString(),
+                                                    tr("SoundFont Files (*.dls *.sf2)"));
     if (fileName.isEmpty()) {
         m_dlsFile.clear();
-        ui->lblDLSFileName->setText("[empty]");
+        ui->lblSFFileName->setText("[empty]");
         ProgramSettings::instance()->setDLSsoundfont(m_dlsFile);
         m_synth->renderer()->initSoundfont(m_dlsFile);
     } else {
@@ -311,9 +314,10 @@ void MainWindow::dropEvent(QDropEvent *event)
             QFileInfo fInfo(path);
             if (fInfo.exists()) {
                 const auto ext = fInfo.suffix().toLower();
-                if (ext == "mid" || ext == "midi" || ext == "kar") {
+                if (ext == "mid" || ext == "midi" || ext == "kar" || ext == "rmi" || ext == "xmf"
+                    || ext == "mxmf") {
                     readSongFile(fInfo);
-                } else if (ext == "dls") {
+                } else if (ext == "dls" || ext == "sf2") {
                     readSoundfont(fInfo);
                 }
             }
